@@ -2,9 +2,15 @@ package FBP::HtmlWindow;
 
 use Mouse;
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
-extends 'FBP::Panel';
+extends 'FBP::Window';
+
+has permission => (
+	is  => 'ro',
+	isa => 'Str',
+	required => 1,
+);
 
 has style => (
 	is  => 'ro',
